==> mhsmm_0.4.4.zip: mhsmm/doc/DHMM1.R <==
###################################################
### chunk number 1: 
###################################################
#line 30 "d:/Rcompile/CRANpkg/local/2.12/mhsmm/inst/doc/DHMM1.Rnw"
options("width"=80)
library(mhsmm)


###################################################
### chunk number 2: 
###################################################
#line 50 "d:/Rcompile/CRANpkg/local/2.12/mhsmm/inst/doc/DHMM1.Rnw"
y1 <- c(1,1,1,1,2,1,1,NA,1,1,2,1,1,1,2,1,1,1,1,1,2,2,2,2,1,2,2,2,1,2,2,2,1,1,1,1,1,1,1,1,2,2,2,1,1) 


###################################################
### chunk number 3: 
###################################################
#line 56 "d:/Rcompile/CRANpkg/local/2.12/mhsmm/inst/doc/DHMM1.Rnw"
obj <- smooth.discrete(y1)


###################################################
### chunk number 4: smooth1
###################################################
#line 64 "d:/Rcompile/CRANpkg/local/2.12/mhsmm/inst/doc/DHMM1.Rnw"
plot(y1, ylim=c(0.8,2))
addStates(obj$s)


###################################################
### chunk number 5: 
###################################################
#line 81 "d:/Rcompile/CRANpkg/local/2.12/mhsmm/inst/doc/DHMM1.Rnw"
y2 <- c(1,1,1,1,2,2,2,1,1,2,1,1,1,2,1,1,1,1,1,2,2,2,NA,1,1,1,2,2,1,2,2,2)
predict(obj,x=y2)


###################################################
### chunk number 6: 
###################################################
#line 93 "d:/Rcompile/CRANpkg/local/2.12/mhsmm/inst/doc/DHMM1.Rnw"
summary(obj)


###################################################
### chunk number 7: 
###################################################
#line 105 "d:/Rcompile/CRANpkg/local/2.12/mhsmm/inst/doc/DHMM1.Rnw"
args(smooth.discrete)


###################################################
### chunk number 8: 
###################################################
#line 116 "d:/Rcompile/CRANpkg/local/2.12/mhsmm/inst/doc/DHMM1.Rnw"
table(y1)/sum(table(y1))


###################################################
### chunk number 9: 
###################################################
#line 123 "d:/Rcompile/CRANpkg/local/2.12/mhsmm/inst/doc/DHMM1.Rnw"
ttt<-table(y1[-length(y1)],y1[-1])
ttt
sweep(ttt, 1, rowSums(ttt), "/")


###################################################
### chunk number 10: 
###################################################
#line 137 "d:/Rcompile/CRANpkg/local/2.12/mhsmm/inst/doc/DHMM1.Rnw"
createTransition(c(0.8,0.9),2)

==> mhsmm_0.4.16.zip: mhsmm/doc/DHMM1.R <==
### R code from vignette source 'DHMM1.Rnw'
### Encoding: UTF-8

###################################################
### code chunk number 1: DHMM1.Rnw:30-32
###################################################
options("width"=80)
library(mhsmm)


###################################################
### code chunk number 2: DHMM1.Rnw:50-51
###################################################
y1 <- c(1,1,1,1,2,1,1,NA,1,1,2,1,1,1,2,1,1,1,1,1,2,2,2,2,1,2,2,2,1,2,2,2,1,1,1,1,1,1,1,1,2,2,2,1,1) 


###################################################
### code chunk number 3: DHMM1.Rnw:56-57
###################################################
obj <- smooth.discrete(y1)


###################################################
### code chunk number 4: smooth1
###################################################
plot(y1, ylim=c(0.8,2))
addStates(obj$s)


###################################################
### code chunk number 5: DHMM1.Rnw:81-83
###################################################
y2 <- c(1,1,1,1,2,2,2,1,1,2,1,1,1,2,1,1,1,1,1,2,2,2,NA,1,1,1,2,2,1,2,2,2)
predict(obj,x=y2)


###################################################
### code chunk number 6: DHMM1.Rnw:93-94
###################################################
summary(obj)


###################################################
### code chunk number 7: DHMM1.Rnw:105-106
###################################################
args(smooth.discrete)


###################################################
### code chunk number 8: DHMM1.Rnw:116-117
###################################################
table(y1)/sum(table(y1))


###################################################
### code chunk number 9: DHMM1.Rnw:123-126
###################################################
ttt<-table(y1[-length(y1)],y1[-1])
ttt
sweep(ttt, 1, rowSums(ttt), "/")


###################################################
### code chunk number 10: DHMM1.Rnw:137-138
###################################################
createTransition(c(0.8,0.9),2)
